# aicuflow-python

use [aicuflow](https://aicuflow.com/?ref=aicuflow-python) in your python apps 🎉

## quickstart

```bash
pip install aicuflow
```

[check the documentation](https://aicuflow.com/docs/library/python)

## contributing

yeees you can contribute to this library!

make sure to follow the soon existing community guidelines!

### version history

using [semver](https://semver.org/lang/de/).

```txt
0.1.0 - basic version containing core file & flow featureset
0.0.1 - initial publishing
```

### contribs quickstart

```bash
# local synced dev install
git clone https://github.com/AICU-HEALTH/aicuflow-python
cd aicuflow
pip install -e .
```

### contrib guide

1. clone (see quickstart)
2. branch (yourname/your-feature-or-fix-name)
3. code (use python-black formatter pls)
4. pull request
5. review (max 3 cycles, usually within 48h)
6. be merged, such cool 🎉

## license: pretty chill

the owners have not decided on a license but shall do so soon

you are permitted to use this however, guaranteedly in any of your tests, educational and commercial apps, billed only for actual aicuflow-core useage.

anything of aicuflow-core is proprietary

if in doubt just call us!
